#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

install_requires = \
['pika']

setup(name='bunnymq',
      version='0.0.8',
      description='Simple messaging with RabbitMQ and Python.',
      author='havefish',
      author_email='havefish@protonmail.com',
      url='https://github.com/havefish/bunnymq',
      py_modules=['bunnymq'],
      install_requires=install_requires,
     )
